# CyberBook
This is a collection of functions / tools that are used frequently enough to store them some place.
Feel free to check out the docs at [CyberBookDocs](https://clutchreboot.github.io/CyberBookDocs/).
